@@ -29,7 +29,7 @@ if TYPE_CHECKING:
 
     Model = TypeVar("Model", bound="BaseModel")
 
-from .compat.yaml_lib import yaml
+from .compat.yaml_lib import yaml_safe_dump, yaml_safe_load
 
 
 ExtendedProto = Union[Protocol, Literal["yaml"]]
@@ -58,8 +58,8 @@ def is_yaml_requested(
 class YamlModelMixinConfig:
     """Additional configuration for YamlModelMixin."""
 
-    yaml_loads: Callable[[str], Any] = yaml.safe_load  # type: ignore
-    yaml_dumps: Callable[..., str] = yaml.safe_dump  # type: ignore
+    yaml_loads: Callable[[str], Any] = yaml_safe_load  # type: ignore
+    yaml_dumps: Callable[..., str] = yaml_safe_dump  # type: ignore
 
 
 class YamlModelMixin(metaclass=ModelMetaclass):
@@ -115,6 +115,7 @@ class YamlModelMixin(metaclass=ModelMetaclass):
         exclude_unset: bool = False,
         exclude_defaults: bool = False,
         exclude_none: bool = False,
+        sort_keys: bool = False,
         default_flow_style: Optional[bool] = False,
         default_style: YamlStyle = None,
         indent: Optional[bool] = None,
@@ -131,6 +132,9 @@ class YamlModelMixin(metaclass=ModelMetaclass):
             Whether to use aliases instead of declared names. Default is False.
         skip_defaults, exclude_unset, exclude_defaults, exclude_none
             Arguments as per `BaseModel.dict()`.
+        sort_keys : bool
+            If True, will sort the keys in alphanumeric order for dictionaries.
+            Default is False, which will dump in the field definition order.
         default_flow_style : bool or None
             Whether to use the "flow" style in the dumper. By default, this is False,
             which uses the "block" style (probably the most familiar to users).
@@ -160,6 +164,7 @@ class YamlModelMixin(metaclass=ModelMetaclass):
         cfg = cast(YamlModelMixinConfig, self.__config__)
         return cfg.yaml_dumps(
             data,
+            sort_keys=sort_keys,
             default_flow_style=default_flow_style,
             default_style=default_style,
             encoding=encoding,
